import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="mesh",
    version="1.4.0",
    author="Mesh Team",
    author_email="info@mesh.com",
    description="Python SDK for the Mesh API with improved authentication",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/udai22/MeshFinal",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=[
        "requests>=2.25.0",
        "keyring>=21.0.0",
        "python-dotenv>=0.15.0",
    ],
    entry_points={
        "console_scripts": [
            "mesh-auth=mesh.auth_cli:main",
        ],
    },
)